<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * Dashboard. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * this starts the plugin.
 *
 * @link:       http://sitogon.ru
 * @since             1.0.0
 * @package           Jivosite_Plugin
 *
 * @wordpress-plugin
 * Plugin Name:       Jivosite Plugin
 * Plugin URI:        http://sitogon.ru
 * Description:        Jivosite Plugin
 * Version:           1.0.0
 * Author:            Vladimir Egorov
 * Author URI:
 * License:            GPL-2.0+
 * License URI:        http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:            jivosite-plugin
 * Domain Path:            /languages
 */

// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}

class Jivosite_Plugin
{
    public $current_url;

    public function __construct()
    {


        load_plugin_textdomain('jivosite-plugin', FALSE, basename(dirname(__FILE__)) . '/languages/');

        add_action('admin_init', array($this, 'register_mysettings'));

        $this->current_url = $this->get_current_URL();

        if (is_admin()) {

            add_action('admin_menu', array($this, 'jivositeplugin_create_menu'));
        } else {
            add_action('wp_footer', array($this, 'include_jivoste'));
        }

    }

    public function jivositeplugin_create_menu()
    {
        add_menu_page('Jivosite Plugin Settings', 'Jivosite', 'manage_options', __FILE__, array($this, 'jivosite_settings_page'));

        add_action('admin_init', array($this, 'register_mysettings'));
    }

    public function register_mysettings()
    {

        register_setting('jivosite-plugin-settings-group', 'jivosite_code');
        register_setting('jivosite-plugin-settings-group', 'urls_for_die');
    }

    public function get_current_URL()
    {
        $current_url = 'http';
        $server_https = $_SERVER["HTTPS"];
        $server_name = $_SERVER["SERVER_NAME"];
        $server_port = $_SERVER["SERVER_PORT"];
        $request_uri = $_SERVER["REQUEST_URI"];
        if ($server_https == "on") $current_url .= "s";
        $current_url .= "://";
        if ($server_port != "80") $current_url .= $server_name . ":" . $server_port . $request_uri;
        else $current_url .= $server_name . $request_uri;
        $url = urldecode (  $current_url  );
        return $url;
    }

    public function jivosite_settings_page()
    {
        ?>
        <style>
            .txt_ar {
                min-width: 400px;
                min-height: 300px;
            }
        </style>
        <div class="wrap">
            <h2><?php echo _e('Plugin Settings', 'jivosite-plugin') ?></h2>

            <h3><?php echo _e('Jivosite URL', 'jivosite-plugin'); ?></h3>

            <form method="post" action="options.php">
                <?php wp_nonce_field('update-options'); ?>
                <?php settings_fields('jivosite-plugin-settings-group'); ?>
                <table class="form-table">
                    <tr valign="top">
                        <th scope="row"><?php echo _e('Your Code', 'jivosite-plugin'); ?></th>
                        <td><textarea class="txt_ar"
                                      name="jivosite_code"><?php echo get_option('jivosite_code'); ?></textarea></td>
                    </tr>

                    <tr valign="top">
                        <th scope="row"><?php echo _e('Url of Pages', 'jivosite-plugin') ?></th>
                        <td><textarea class="txt_ar"
                                      name="urls_for_die"><?php echo get_option('urls_for_die'); ?></textarea></td>
                    </tr>

                </table>

                <p class="submit">
                    <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>"/>
                </p>
                <input type="hidden" name="page_options" value="jivosite_code,urls_for_die"/>
                <input type="hidden" name="action" value="update"/>
            </form>
        </div>

    <?php }


    public function include_jivoste()
    {
        $action_insert = 1;

        $urls = get_option('urls_for_die');

        if ($urls && $urls != '') {

            $urls_array = explode(',', $urls);


            foreach ($urls_array as $value) {
                $url = trim($value);

                $check = strpos($this->current_url, $url);

                if ($check != false) {
                    $action_insert = 0;
                }
            }

        }



        if (get_option('jivosite_code') && get_option('jivosite_code') != '' && $action_insert == 1) {
            $script = get_option('jivosite_code');;
            echo $script;
        }
    }


}

$plugin = new Jivosite_Plugin();


